==> tencentcloud-sdk-java-3.1.97-sources.jar: com/tencentcloudapi/bm/v20180423/models/DescribeRepairTaskConstantResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.bm.v20180423.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeRepairTaskConstantResponse extends AbstractModel{

    /**
    * 故障类型ID与对应中文名列表
    */
    @SerializedName("TaskTypeSet")
    @Expose
    private TaskType [] TaskTypeSet;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 故障类型ID与对应中文名列表 
     * @return TaskTypeSet 故障类型ID与对应中文名列表
     */
    public TaskType [] getTaskTypeSet() {
        return this.TaskTypeSet;
    }

    /**
     * Set 故障类型ID与对应中文名列表
     * @param TaskTypeSet 故障类型ID与对应中文名列表
     */
    public void setTaskTypeSet(TaskType [] TaskTypeSet) {
        this.TaskTypeSet = TaskTypeSet;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "TaskTypeSet.", this.TaskTypeSet);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}

==> tencentcloud-sdk-java-3.1.607-sources.jar: com/tencentcloudapi/bm/v20180423/models/DescribeRepairTaskConstantResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.bm.v20180423.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeRepairTaskConstantResponse extends AbstractModel{

    /**
    * 故障类型ID与对应中文名列表
    */
    @SerializedName("TaskTypeSet")
    @Expose
    private TaskType [] TaskTypeSet;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 故障类型ID与对应中文名列表 
     * @return TaskTypeSet 故障类型ID与对应中文名列表
     */
    public TaskType [] getTaskTypeSet() {
        return this.TaskTypeSet;
    }

    /**
     * Set 故障类型ID与对应中文名列表
     * @param TaskTypeSet 故障类型ID与对应中文名列表
     */
    public void setTaskTypeSet(TaskType [] TaskTypeSet) {
        this.TaskTypeSet = TaskTypeSet;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public DescribeRepairTaskConstantResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DescribeRepairTaskConstantResponse(DescribeRepairTaskConstantResponse source) {
        if (source.TaskTypeSet != null) {
            this.TaskTypeSet = new TaskType[source.TaskTypeSet.length];
            for (int i = 0; i < source.TaskTypeSet.length; i++) {
                this.TaskTypeSet[i] = new TaskType(source.TaskTypeSet[i]);
            }
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "TaskTypeSet.", this.TaskTypeSet);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}
